import { get, post } from './request';

interface Params { }

// 校验token接口
export const checkToken = () => {
	return get("/user/check/status");
};
/* 搜索 */
export const searchApi = {
	/* 获取搜索推荐词 */
	getKeys: (params: Params) => {
		return get("/config/detail", params);
	},
	/* 搜索  KeyWord */
	getResult: (params: Params) => {
		return get("/search/list", params);
	},
	/* 报告搜索  KeyWord */
	getResultReport: (params: Params) => {
		return get("/search/report/list", params);
	},
};



interface HomeListParams {
	PageSize: number;
	CurrentIndex: number;
	ChartPermissionId: number
}
/* 用户模块 */
export const summaryApi = {
	/**
	 * 获取图表详情
	 * @param params UniqueCode 
	 * @returns 
	 */
	getList: (params: HomeListParams) => {
		return get('/home/list', params);
	},
	/* 获取品种 */
	Tab: (params: Params) => {
		return get("/permission/all", params);
	},
}



/* 搜索 */
export const Report = {
	/* 获取搜索推荐词 */
	reportDtl: (params: Params) => {
		return get("/article/detail", params);
	},
	/* 申请访谈 ArticleId*/
	applyRpt: (params: Params) => {
		return post('/article/interview/apply', params)
	},
	/* 收藏 ArticleId*/
	collectRpt: (params: Params) => {
		return post('/article/collect', params)
	},
	/* 关注作者/取消关注作者 接口 DepartmentId*/
	fllowDepartment: (params: Params) => {
		return post('/report/fllowDepartment', params)
	},
	/* 新增文章带问接口 ArticleId*/
	articleAskAdd: (params: Params) => {
		return post("/article/askAdd", params);
	},
	/* 获取报告详情接口 /  路演精华*/
	roadshowEssence: (params: Params) => {
		return get("/report/roadshowEssence/detail", params);
	},
	/* 获取报告精选详情接口*/
	reportSelectionDetail: (params: Params) => {
		return get("/report/reportSelection/detail", params);
	},
	/* 获取本周研究汇总详情接口*/
	researchSummaryDetail: (params: Params) => {
		return get("/report/researchSummary/detail", params);
	},
	/* 获取上周研究汇总详情接口*/
	minutesSummaryDetail: (params: Params) => {
		return get("/report/minutesSummary/detail", params);
	},
	/* 页面复制监听*/
	pageHistoryCopy: (params: Params) => {
		return post('/config/pageHistory', params)
	},
};
/*user 用户 */
export const User = {
	applyTry: (params: Params) => {
		return post("/user/apply/try", params);
	},
	/* 用户信息 */
	getInfo: (params: Params) => {
		return get("/user/detail", params);
	},
	/* 获取手机验证码  Mobile * AreaNum */
	getPhoneCode: (params: Params) => {
		return get("/wechat/getSmsCode", params);
	},
	/* 获取邮件验证码  Email */
	getEmailCode: (params: Params) => {
		return get("/wechat/getEmailCode", params);
	},
	/* 
  登录 绑定手机号邮箱
  "Email": "string",
   "LoginType": 0 1手机号 2邮箱,
   "Mobile": "string"
   */
	Bind: (params: Params) => {
		return post("/user/login", params);
	},
	//获取是否需要填写区号接口
	countryCcode: () => {
		return get("/user/countryCcode/isNeedAdd");
	},
	//上传用户区号接口
	countryCcodeAdd: (params: Params) => {
		return post("/user/countryCcode/Add", params);
	},
}
/* 活动  */
export const activity = {
	/*用户修改外呼手机号以及区号接口*/
	addOutboundMobile: (params: Params) => {
		return post("/user/countryCcode/addOutboundMobile", params);
	},
	/* 获取活动列表接口*/
	getActivityList: (params: Params) => {
		return get("/activity/list", params);
	},
	/* 获取活动列表接口*/
	getActivityDetail: (params: Params) => {
		return get("/activity/detail", params);
	},
	/* 获取活动行业接口*/
	getUserSearchContent: (params: Params) => {
		return get("/activity/getUserSearchContent", params);
	},
	/* 活动报名接口*/
	signupAdd: (params: Params) => {
		return post("/activity/signup/add", params);
	},
	/* 活动取消报名接口*/
	signupCancel: (params: Params) => {
		return post("/activity/signup/cancel", params);
	},
	/* 获取活动列表接口*/
	getScheduleList: (params: Params) => {
		return get("/activity/scheduleList", params);
	},
	/* 活动取消报名接口*/
	meetingReminderAdd: (params: Params) => {
		return post("/activity/meetingReminder/add", params);
	},
	/* 取消消息提醒接口*/
	meetingReminderCancel: (params: Params) => {
		return post("/activity/meetingReminder/cancel", params);
	},
	/* 获取敏捷搜索关键词的列表接口*/
	fastSearchKeWord: (params: Params) => {
		return get("/activity/labelMoreList", params);
	},
	/*新增活动带问接口*/
	activityAskAdd: (params: Params) => {
		return post("/activity/askAdd", params);
	},
	/*获取研选说明接口*/
	descriptionOfResearch: (params: Params) => {
		return get("/config/descriptionOfResearch", params);
	},
	/*获取主题活动接口*/
	getActivityListNew: (params: Params) => {
		return get("/activity/listNew", params);
	},
	/*获取活动类型下的主题列表接口（4.3版本）*/
	getActivityLabelTypeList: (params: Params) => {
		return get("/activity/labelTypeListV6Pc", params);
	},
	/* 校验活动带问是否有权限接口 */
	checkAskActivity: (params: Params) => {
		return post("/activity/checkAsk", params);
	},
	/*获取专项产业调研列表接口*/
	getSpecialDetailList: (params: Params) => {
		return get("/activity/special/detail", params);
	},
	/*感兴趣、不感兴趣接口*/
	postSpecialSignupAdd: (params: Params) => {
		return post("/activity/special/signup/add", params);
	},
	/*专项调研的通知 和取消通知*/
	postSpecialFollow: (params: Params) => {
		return post("/activity/special/follow", params);
	},
	/*获取专项产业调研列表接口*/
	getSpecialList: (params: Params) => {
		return get("/activity/special/list", params);
	},
	/*预约纪要接口*/
	postAppointmentAdd: (params: Params) => {
		return post("/activity/appointment/add", params);
	},
	/*取消预约纪要接口*/
	postAppointmentCancel: (params: Params) => {
		return post("/activity/appointment/cancel", params);
	},
}


/* 报告  */
export const Reports = {
	/* 获取报告一级分类 */
	getClassify: () => {
		return get("/permission/reportallV7");
	},
	/* 获取产业文章列表接口*/
	getIndustryAndArticle: (params: Params) => {
		return get("/report/searchResource", params);
	},
	/* 获取策略列表接口*/
	getTactics: (params: Params) => {
		return get("/tactics/list", params);
	},
	/* 获取策略的分类 */
	getstrategyAll: () => {
		return get("/permission/strategyAll");
	},
	/* 报告研选*/
	industryListByDepartment: (params: Params) => {
		return get("/report/industryListByDepartmentPc", params);
	},
	/* 产业下所关联的文章分类列表接口*/
	toArticleCategoryList: (params: Params) => {
		return get("/report/toArticleCategoryList", params);
	},
	/* 产业下所关联的文章分类列表接口*/
	getArticleList: (params: Params) => {
		return get("/report/industry/ArticleList", params);
	},
	/* 关注作者/取消关注作者 接口*/
	reportFllowDepartment: (params: Params) => {
		return post("/report/fllowDepartment", params);
	},
	/* 获取产业报告分类列表接口*/
	getTradeList: (params: Params) => {
		return get("/report/home/tradeList", params);
	},
	/* 获取产业报告分类列表接口*/
	getIndustryList: (params: Params) => {
		return get("/report/home/industryList", params);
	},
	/* 关注/取消关注 接口 */
	reportFllow: (params: Params) => {
		return post("/report/fllow", params);
	},
	/* 获取研选最新主题关键词文章列表接口*/
	reportListNew: (params: Params) => {
		return get("/report/industry/reportListNew", params);
	},
	/* 获取报告精选详情接口*/
	reportSelectionDetail: (params: Params) => {
		return get("/report/reportSelection/detail", params);
	},
	/* 获取本周研究汇总详情接口*/
	researchSummaryDetail: (params: Params) => {
		return get("/report/researchSummary/detail", params);
	},
	/* 获取上周研究汇总详情接口*/
	minutesSummaryDetail: (params: Params) => {
		return get("/report/minutesSummary/detailv4", params);
	},
	/*上传文章阅读时间接口*/
	addStopTime: (params: Params) => {
		return post("/article/addStopTime", params);
	},
	/* 下载PDF打水印接口*/
	articlePdfwatermark: (params: Params) => {
		return get('/article/pdfwatermark', params)
	},
	/* 报告搜索接口*/
	getReportSearchReport: (params:Params) => {
		return get("/report/searchReport", params);
	},
	/* 产业报告公司列表 */
	getHomeStockName: (params:Params) => {
		return get("/report/home/stockName", params);
	},
}

export const Chart = {
	/*图表标签分类接口*/
	getChartPatg: (params: Params) => {
		return get("/chart/patg", params);
	},
	/*我的收藏接口*/
	getChartcollection: (params: Params) => {
		return get("/chart/my/collection", params);
	},
	/*删除我的收藏接口*/
	myChartCollect: (params: Params) => {
		return post("/chart/collect", params);
	},
	/*图表的详情*/
	myChartDetail: (params: Params) => {
		return get("/chart/detail", params);
	},
	/*图表的详情*/
	myChartTop: (params: Params) => {
		return post("/chart/top", params);
	},
	/* 
   列表
   PageSize * CurrentIndex * ChartPermissionId *品类id，最新传0
   */
	getList: (params: Params) => {
		return get("/home/artAndChart/list", params);
	},
	/* 报告 KeyWord 素材库*/
	getArtAndChartList: (params: Params) => {
		return get("/search/artAndChart/list", params);
	},
};

export const Research = {
	/* 近期更新主题列表接口 */
	researchNewList: (params: Params) => {
		return get("/research/theme/newList", params);
	},
	/* 用户收藏列表接口 */
	researchCollectionList: (params: Params) => {
		return get("/research/collectionList", params);
	},
	/* 主题热度/近期更新更多,列表接口 */
	researchHotList: (params: Params) => {
		return get("/research/hotList", params);
	},
	/* KOL榜列表接口 */
	researchKolList: (params: Params) => {
		return get("/research/kolList", params);
	},
	/* 研选作者详情接口 */
	departmentIdDetail: (params: Params) => {
		return get("/research/departmentId/detail", params);
	},
	/* 研选作者详情接口 */
	researchThemeDetail: (params: Params) => {
		return get("/research/theme/detail", params);
	},
	/* 热搜关键词接口 */
	researchHotKeyWord: (params: Params) => {
		return get("/research/hotKeyWord", params);
	},
};


