import { createRouter, RouteRecordRaw, createWebHistory } from 'vue-router';
import store from "@/store";

// 扩展路由配置 额外参数
export type AppRouteRecordRaw = RouteRecordRaw & {
	hidden?: boolean
}
const layout = () => import('@/views/layout/index.vue')

export const routes: AppRouteRecordRaw[] = [
	{
		path: '/',
		component: layout,
		name: 'layout',
		hidden: false,
		redirect: '/index',
	},

	/*
	纪要库
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/index',
			component: () => import('@/views/summary/index.vue'),
			name: '纪要库',
		},
		{
			path: '/reportDetail',
			component: () => import('@/views/details/index.vue'),
			name: '详情',
			meta: {
				pathFrom: '/index',
				pathName: '纪要库',
			}
		},
		{
			path: '/applyTrial',
			component: () => import('@/views/applyTrial/index.vue'),
			name: '申请',
			meta: {
				pathFrom: '/index',
				pathName: '纪要库',
			}
		},
		{
			path: '/indexSearch',
			component: () => import('@/views/summary/search.vue'),
			name: '纪要库搜索',
			meta: {
				pathFrom: '/index',
				pathName: '纪要库',
			}
		},
		]
	},

	/*
	产业报告
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/reportForm',
			component: () => import('@/views/report/index.vue'),
			name: '报告',
		},
		{
			path: '/detail',
			component: () => import('@/views/details/index.vue'),
			name: 'repore详情',
			meta: {
				pathFrom: '/reportForm',
				pathName: '报告',
			}
		},
		{
			path: '/reportSearch',
			component: () => import('@/views/report/search.vue'),
			name: '报告搜索',
			meta: {
				pathFrom: '/reportForm',
				pathName: '报告',
			}
		},
		{
			path: '/IndustryReport',
			component: () => import('@/views/report/strategyList.vue'),
			name: '报告列表页面',
			meta: {
				pathFrom: '/reportForm',
				pathName: '报告',
			}
		},
		{
			path: '/yearWeek',
			component: () => import('@/views/report/yearWeek.vue'),
			name: '周/年',
			meta: {
				pathFrom: '/reportForm',
				pathName: '报告',
			}
		},
		]
	},

	/*
	买方研选
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/purchaser',
			component: () => import('@/views/purchaser/index.vue'),
			name: '买方研选',
		},
		{
			path: '/allTheme',
			component: () => import('@/views/purchaser/allTheme.vue'),
			name: '更多主题',
			meta: {
				pathFrom: '/purchaser',
				pathName: '买方研选',
			}
		},
		{
			path: '/themeDetails',
			component: () => import('@/views/purchaser/themeDetails.vue'),
			name: '主题详情',
			meta: {
				pathFrom: '/purchaser',
				pathName: '买方研选',
			}
		},
		{
			path: '/authorPage',
			component: () => import('@/views/purchaser/authorPage.vue'),
			name: '作者详情',
			meta: {
				pathFrom: '/purchaser',
				pathName: '买方研选',
			}
		},
		{
			path: '/purchaserSearch',
			component: () => import('@/views/report/search.vue'),
			name: '买方研选搜索',
			meta: {
				pathFrom: '/purchaser',
				pathName: '买方研选',
			}
		},
		]
	},

	/*
	活动
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/activity',
			component: () => import('@/views/activity/index.vue'),
			name: '活动',
		},
		{
			path: '/themeActivity',
			component: () => import('@/views/activity/component/themeActivity.vue'),
			name: '主题活动',
			meta: {
				pathFrom: '/activity',
				pathName: '活动',
				keepAlive: false
			}
		},
		{
			path: '/activityDetail',
			component: () => import('@/views/activity/component/activityDetails.vue'),
			name: '活动详情',
			meta: {
				pathFrom: '/activity',
				pathName: '活动',
				keepAlive: false
			}
		},
		{
			path: '/specialDetail',
			component: () => import('@/views/activity/component/specialDetail.vue'),
			name: '专项调研详情',
			meta: {
				pathFrom: '/activity',
				pathName: '活动',
				keepAlive: false
			}
		},
		{
			path: '/specialResearchPage',
			component: () => import('@/views/activity/component/specialResearchPage.vue'),
			name: '专项产业调研',
			meta: {
				pathFrom: '/activity',
				pathName: '活动',
				keepAlive: false
			}
		},
		]
	},

	/*
	图表
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/chart',
			component: () => import('@/views/chart/index.vue'),
			name: '图表',
		},
		{
			path: '/chartSeach',
			component: () => import('@/views/chart/search.vue'),
			name: '图表搜索',
			meta: {
				pathFrom: '/chart',
				pathName: '图表',
			}
		},
		{
			path: '/chartPage',
			component: () => import('@/views/chart/chartDetail.vue'),
			name: '图表详情',
			meta: {
				pathFrom: '/chart',
				pathName: '图表',
			}
		},
		]
	},

	/*
	报告详情
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/reportSecretDetail',
			component: () => import('@/views/secretDetails/index.vue'),
			name: '报告详情',
		}]
	},

	/*
	路演精华
	*/
	{
		path: '/',
		component: layout,
		children: [{
			path: '/roadEssence',
			component: () => import('@/views/roadEssence/index.vue'),
			name: '路演精华',
		}]
	},

];

const router = createRouter({
	history: createWebHistory(import.meta.env.BASE_URL), //路由模式
	routes,
});

let NUM_TOKEN = 1 //定义初始的数值 来判断是返回按键的隐藏显示
router.beforeEach((to, from, next) => {
	if (NUM_TOKEN === 1) {
		!store.state.token && store.commit('getToken', to.query.token) //判断 储存 token
	}
	store.commit('getBackState', NUM_TOKEN) //通过vuex 来传递值
	NUM_TOKEN++

	next();
})

export default router;
