import { InjectionKey } from 'vue'
import { createStore, Store } from 'vuex';
import { checkToken, User } from '@/request/api'
interface IsToken {
  token: string;
}

export const key: InjectionKey<Store<IsToken>> = Symbol();

const store = createStore({
  state: {
    token: '',
    userInfoData: {},
    authBind: {},
    goBackState: 1,
    routerKeepAlive: [],
  },
  mutations: {
    getToken(state, payload) {
      state.token = payload
    },
    getUser(state, payload) {
      state.userInfoData = payload
    },
    getAuthBind(state, payload) {
      state.authBind = payload
    },
    getBackState(state, payload) {
      state.goBackState = payload
    },
    setKeepAlive(state, payload) {
      state.routerKeepAlive = payload
    }
  },
  actions: {
    checkHandle(context) {
      return new Promise((resolve, reject) => {
        checkToken().then((res) => {
          context.commit('getAuthBind', res.Data)
          if (res.Ret === 200) {
            resolve(res)
          }
        })
          .catch((err) => {
            reject(err);
          });
      });
    },
    async getUserInfo(context) {
      const res = await User.getInfo({});
      if (res.Ret === 200) {
        res.Data.PermissionName = res.Data.PermissionName && res.Data.PermissionName.replace(/,/g, "/");
        context.commit('getUser', res.Data)
      }
    }
  }
});

export default store;